#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-9OXn36PZoadjDpZn8mjiB
key:                  gitit-0.15.1.2-9OXn36PZoadjDpZn8mjiB
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  d3a0284d652dc6d8a4ba9f812e0d6173
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-9OXn36PZoadjDpZn8mjiB
depends:
    HStringTemplate-0.8.8-LLUf8BbFlSVHy7P2WYUOBm
    HTTP-4000.4.1-K9whznG0VY9E38dui1XqaI
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ base-4.18.2.1
    base64-bytestring-1.2.1.0-HTSPucLWQY58n8fXtuig9
    blaze-html-0.9.2.0-rarmgesoctDq9bbbK0fHM bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-EKJmqjyxllPB38wdGBZpbA
    feed-1.3.2.1-E1psbRa6WfL8UTQy6VY0JJ filepath-1.4.300.1
    filestore-0.6.5.1-EZEYbpH84XcLGcSMMo2g3S ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-Ji6CCVDNM7dryH8Hu5AvO
    hoauth2-2.14.0-DNZxUw8Okoa5wXafE4XEPJ
    hslogger-1.3.2.0-Kn95eZlubchAss7oQg7dU6
    http-client-tls-0.3.6.4-A4oTFfT0Noh4Qsq9wNW0bZ
    http-conduit-2.3.9.1-FTVHEfOvSDTGYak0XiiraO
    json-0.10-1QJiKosvYy8EUt14ONR1FW mtl-2.3.1
    network-3.1.4.0-DnyUe3C7n48FET4frYkCJy
    network-bsd-2.8.1.0-3UZo0PWC4vZ3hINXXZ9GY8
    network-uri-2.6.4.2-9M7dxRCc55s4u87L8Rdwuk
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG
    pandoc-3.6-3eK3JhhkrsoHJBwXTARl2i
    pandoc-types-1.23.1-4ixGGX9TbW393jf05DapBw parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-F4yImuU8Eln1YUMUzrSOOB
    recaptcha-0.1.0.4-A1tlx9XcnOrF2ksUXJFwl4
    safe-0.3.21-4vr9angs8ljJ6x4nxPJqmD
    skylighting-0.14.4-7SA0rJHAZIvFnRkwUKyXtm
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-45RHZbqQsU9HukQlnlXSjw
    tagsoup-0.14.8-KFQxmtBUzNB86DIV8OFUQy
    temporary-1.3-AHYrzBcWpv98oJG4OGs0iG text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-2efJke6NDQcCHfrubyZMwo
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-JBsG8BFztZsFR9NnAFqfnJ xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-5NcvZLRcSVv2Y8J8pEe1P7
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-5fLyLhmBLmeJpA8JQ946T9
    zlib-0.7.1.0-85JXVpISFMb3ukn1fRabTy

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

